@@ -6,14 +6,16 @@ from efl import edje
 from efl.edje import Edje
 
 import os, unittest
+import logging
 
 
 theme_path = os.path.dirname(os.path.abspath(__file__))
 theme_file = os.path.join(theme_path, "theme.edj")
 
 
-expected_signals = ["edje,state,ltr", "load", "edje,state,ltr", "resize",
-                    "cursor,changed", "changed", "emit,message", "emit,message"]
+expected_signals = ["edje,language,none", "edje,state,ltr", "load",
+                    "edje,state,ltr", "resize",
+                    "emit,message", "emit,message"]
 expected_signals2 = ["load", "resize"]
 expected_messages = [33, 33]
 expected_text_parts = ["label", "label"]
@@ -26,12 +28,13 @@ class MyEdje(Edje):
 
     @edje.on_signal("*", "*")
     def cb_signal_all(self, emission, source):
-        expected_signals.remove(emission)
+        if source == "" or source == "edje":
+            expected_signals.remove(emission)
 
     @edje.on_signal("load", "*")
     @edje.on_signal("resize", "*")
     def cb_signal_load_resize(self, emission, source):
-         expected_signals2.remove(emission)
+        expected_signals2.remove(emission)
 
     @edje.message_handler
     def message_handler(self, msg):
@@ -48,13 +51,16 @@ class TestEdjeDecoratedCallbacks(unittest.TestCase):
                                   size=(400, 500),
                                   viewport=(0, 0, 400, 500))
         self.canvas.engine_info_set(self.canvas.engine_info_get())
+        self.o = MyEdje(self.canvas)
+        self.assertIsInstance(self.o, Edje)
 
     def tearDown(self):
+        self.o.delete()
+        self.assertTrue(self.o.is_deleted())
         self.canvas.delete()
 
     def testDecorators(self):
-        o = MyEdje(self.canvas)
-        self.assertIsInstance(o, Edje)
+        o = self.o
 
         # this should trigger text_change, two times
         ecore.Timer(0.1, lambda: o.part_text_set("label", "asd"))
@@ -74,9 +80,12 @@ class TestEdjeDecoratedCallbacks(unittest.TestCase):
         self.assertEqual(expected_messages, [])
         self.assertEqual(expected_text_parts, [])
 
-        o.delete()
-        self.assertTrue(o.is_deleted())
-
 
 if __name__ == '__main__':
+    formatter = logging.Formatter("[%(levelname)s] %(name)s (%(filename)s: %(lineno)d) --- %(message)s")
+    handler = logging.StreamHandler()
+    handler.setFormatter(formatter)
+    efllog = logging.getLogger("efl")
+    efllog.addHandler(handler)
+    efllog.setLevel(logging.DEBUG)
     unittest.main(verbosity=2)
