@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 
 import unittest
+import logging
 
 from efl.eo import Eo
 from efl import elementary
@@ -52,4 +53,10 @@ class TestElmBasics(unittest.TestCase):
 
 
 if __name__ == '__main__':
+    formatter = logging.Formatter("[%(levelname)s] %(name)s (%(filename)s: %(lineno)d) --- %(message)s")
+    handler = logging.StreamHandler()
+    handler.setFormatter(formatter)
+    efllog = logging.getLogger("efl")
+    efllog.addHandler(handler)
+    efllog.setLevel(logging.DEBUG)
     unittest.main(verbosity=2)
