@@ -2,6 +2,7 @@
 
 import os
 import unittest
+import logging
 
 from efl.eo import Eo
 from efl.evas import Image as evasImage
@@ -30,13 +31,14 @@ class TestElmImage(unittest.TestCase):
 
     def testImageFile(self):
         self.o.file = os.path.join(script_path, u"icon.png")
-        self.assertEqual(
-            self.o.file[0], os.path.join(script_path, u"icon.png"))
+        self.assertEqual(self.o.file[0],
+                         os.path.join(script_path, u"icon.png"))
         self.assertEqual(self.o.object_size, (48, 48))
 
     def testImageFileException(self):
-        self.assertRaises(
-            RuntimeError, setattr, self.o, "file", u"this_fails.png")
+        self.assertRaises(RuntimeError,
+                          setattr, self.o, "file",
+                          u"this_fails.png")
 
     def testImageEvas(self):
         self.assertIsInstance(self.o.object, evasImage)
@@ -70,6 +72,7 @@ class TestElmImage(unittest.TestCase):
         self.o.smooth = False
         self.assertFalse(self.o.smooth)
 
+
 class TestElmIcon(unittest.TestCase):
 
     def setUp(self):
@@ -89,8 +92,15 @@ class TestElmIcon(unittest.TestCase):
         self.assertEqual(u"elementary", self.o.standard)
 
     def testIconStandardException(self):
-        self.assertRaises(
-            RuntimeWarning, setattr, self.o, "standard", u"this_fails")
+        self.assertRaises(RuntimeWarning,
+                          setattr, self.o, "standard",
+                          u"this_fails")
 
 if __name__ == '__main__':
+    formatter = logging.Formatter("[%(levelname)s] %(name)s (%(filename)s: %(lineno)d) --- %(message)s")
+    handler = logging.StreamHandler()
+    handler.setFormatter(formatter)
+    efllog = logging.getLogger("efl")
+    efllog.addHandler(handler)
+    efllog.setLevel(logging.DEBUG)
     unittest.main(verbosity=2)
